# OptionalColor

A color that can either be fully opaque or fully transparent.

**Type:** object

## Properties

- **color** ([Color](color.md)): If set, this will be used as an opaque color. If unset, this represents a transparent color.
